@@ -20,7 +20,7 @@
 
 package Glib::Object::Subclass;
 
-our $VERSION = '1.3292';
+our $VERSION = '0.03';
 
 use Glib;
 
@@ -223,18 +223,16 @@ do that.  Especially watch out for other classes in your ISA tree.
 *new = \&Glib::Object::new;
 
 sub import {
-   shift;  # $self
-
    # we seem to be imported by classes using classes which use us.
    # ignore anything that doesn't look like a registration attempt.
-   return unless @_;
+   return unless @_ > 1;
 
-   my $superclass = shift;
+   my ($self, $superclass, %arg) = @_;
    my $class = caller;
 
    Glib::Type->register_object(
       $superclass, $class,
-      @_,
+      %arg,
    );
 
    # ensure that we have a perlish new().  the old version of this
@@ -327,7 +325,7 @@ GLib pulls some fancy tricks with function pointers to implement methods
 in C.  This is not very language-binding-friendly, as you might guess.
 
 However, as described above, every signal allows a "class closure"; you
-may override the class closure with your own function, and you can chain
+may override thie class closure with your own function, and you can chain
 from the overridden method to the original.  This serves to implement
 virtual overrides for language bindings.
 
